package
Version:
v0.0.0-...-b26f8fd
Opens a new window with list of versions in this module.
Published: May 24, 2016
License: Apache-2.0
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 1
Opens a new window with list of known importers.
Documentation
¶
func (s *Map) Delete(key interface{})
func (s *Map) Get(key interface{}) interface{}
func (s *Map) Set(key interface{}, vaule interface{})
Source Files
¶
Click to show internal directories.
Click to hide internal directories.